@@ -118,13 +118,13 @@ func (s *Action) generateCopyOrPrint(ctx context.Context, c *cli.Context, name,
 	// copy to clipboard if:
 	// - explicitly requested with -c
 	// - autoclip=true, but only if output is not being redirected.
-	if IsClip(ctx) || (s.cfg.GetBool("generate.autoclip") && ctxutil.IsTerminal(ctx)) {
-		if err := clipboard.CopyTo(ctx, name, []byte(password), s.cfg.GetInt("core.cliptimeout")); err != nil {
+	if IsClip(ctx) || (config.AsBool(s.cfg.Get("generate.autoclip")) && ctxutil.IsTerminal(ctx)) {
+		if err := clipboard.CopyTo(ctx, name, []byte(password), config.AsInt(s.cfg.Get("core.cliptimeout"))); err != nil {
 			return exit.Error(exit.IO, err, "failed to copy to clipboard: %s", err)
 		}
 		// if autoclip is on and we're not printing the password to the terminal
 		// at least leave a notice that we did indeed copy it.
-		if s.cfg.GetBool("generate.autoclip") && !c.Bool("print") {
+		if config.AsBool(s.cfg.Get("generate.autoclip")) && !c.Bool("print") {
 			out.Print(ctx, "Copied to clipboard")
 
 			return nil
@@ -177,7 +177,7 @@ func (s *Action) generatePassword(ctx context.Context, c *cli.Context, length, n
 		symbols = c.Bool("symbols")
 	} else {
 		if cfg.GetM(mp, "generate.symbols") != "" {
-			symbols = cfg.GetBoolM(mp, "generate.symbols")
+			symbols = config.AsBool(cfg.GetM(mp, "generate.symbols"))
 		}
 	}
 
@@ -521,5 +521,5 @@ func isStrict(ctx context.Context, c *cli.Context) bool {
 	}
 
 	// if the config option is not set, GetBoolM will return false by default
-	return cfg.GetBoolM(mp, "generate.strict")
+	return config.AsBool(cfg.GetM(mp, "generate.strict"))
 }
